// $Id: DefaultOptions.h,v 1.25 2011/06/15 07:14:47 hpereira Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.	See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* software; if not, write to the Free Software Foundation, Inc., 59 Temple
* Place, Suite 330, Boston, MA	02111-1307 USA
*
*
*******************************************************************************/

/*!
\file DefaultOptions.h
\brief default options
\author Hugo Pereira
\version $Revision: 1.25 $
\date $Date: 2011/06/15 07:14:47 $
*/

#include "File.h"
#include "Util.h"
#include "XmlOptions.h"

//_____________________________________________________
//! default options installer
void installDefaultOptions( void )
{

    XmlOptions::get().setAutoDefault( true );

    // set options default values
    XmlOptions::get().set( "ICON_PIXMAP", Option( ":/icon.png" , "application icon"  ) );

    // transparency options
    XmlOptions::get().set( "SPACING", Option( "5", "space between buttons and window border") );
    XmlOptions::get().set( "MARGIN", Option( "5", "space between consecutive buttons") );
    XmlOptions::get().set( "TRANSPARENCY_FOREGROUND_COLOR", Option( "white", "foreground color" ) );
    XmlOptions::get().set( "TRANSPARENCY_FOREGROUND_INTENSITY", Option( "0.3", "foreground bar intensity (in [0,1])" ) );

    XmlOptions::get().set( "TRANSPARENCY_SHADOW_COLOR", Option( "black", "text shadow color" ) );
    XmlOptions::get().set( "TRANSPARENCY_SHADOW_OFFSET", Option( "1", "offset between text shadow and text" ) );

    XmlOptions::get().set( "TRANSPARENCY_TINT_COLOR", Option( "white", "tint color") );
    XmlOptions::get().set( "TRANSPARENCY_TINT_INTENSITY", Option( "0.3", "tint intensity (in [0,1])" ) );
    XmlOptions::get().set( "TRANSPARENCY_OPACITY", Option( "230", "opacity (composite)" ) );

    XmlOptions::get().set( "TRANSPARENCY_HIGHLIGHT_COLOR", Option( "white", "highlight color") );
    XmlOptions::get().set( "TRANSPARENCY_HIGHLIGHT_INTENSITY", Option( "0.3", "highlight color") );

    XmlOptions::get().set( "GRID", Option( "1", "grid size (in pixel) for moving windowsz" ) );
    XmlOptions::get().set( "TRANSPARENT", Option( "1", "1 use transparent background" ) );

    XmlOptions::get().set( "USE_STYLED_TOOLTIPS", Option( "0", "tooltips are drawn using widget style" ) );

    // normal (overwritten) options
    XmlOptions::get().set( "DEFAULT_ICON_PATH", Option( "/usr/share/icons" , "default icon path"  ) );
    XmlOptions::get().set( "NO_HIGHLIGHT", Option( "0" , "use hightlight for clicked buttons"  ) );
    XmlOptions::get().set( "HIGHLIGHT_ON_ENTER", Option( "0" , "use hightlight for clicked buttons"  ) );
    XmlOptions::get().set( "HIGHLIGHT_ON_CLICK", Option( "1" , "use hightlight for clicked buttons"  ) );
    XmlOptions::get().set( "HIGHLIGHT_INTENSITY", Option( "0.5" , "button highlight intensity"  ) );
    XmlOptions::get().set( "HIGHLIGHT_STEPS", Option( "5" , "button highlight steps"  ) );
    XmlOptions::get().set( "MAX_BUTTON_SIZE", Option( "72" , "icon size on display"  ) );
    XmlOptions::get().set( "MIN_BUTTON_SIZE", Option( "38" , "icon size on display"  ) );
    XmlOptions::get().set( "SHOW_TOOLTIP", Option( "1" , "show tooltips"  ) );
    XmlOptions::get().set( "ROUND_TOOLTIP", Option( "1" , "show tooltips"  ) );
    XmlOptions::get().set( "TRANSPARENT_TOOLTIP", Option( "1", "transparent tooltips" ) );
    XmlOptions::get().set( "TOOLTIP_DELAY", Option( "500" , "delay before showing tooltip"  ) );
    XmlOptions::get().set( "TOOLTIP_HEIGHT", Option( "80" , "tooltip window height (pixels)"  ) );
    XmlOptions::get().set( "USE_BIG_PIXMAP", Option( "1" , "big pixmaps in tool buttons"  ) );
    XmlOptions::get().set( "USE_TEXT_LABEL", Option( "1" , "text label in tool buttons"  ) );
    XmlOptions::get().set( "ZOOM_DELAY", Option( "10" , "delay while zooming (milliseconds)"  ) );

    XmlOptions::get().set( "APP_NAME", Option( "TASKBAR", Option::NONE ) );
    XmlOptions::get().set( "HELP_FILE", Option(  File( ".taskbar_qt4_help" ).addPath( Util::home() ), Option::NONE ) );
    XmlOptions::get().set("RC_FILE", Option( File(".taskbar_qt4_rc").addPath( Util::home() ), Option::NONE ) );
    XmlOptions::get().set("XML_FILE", Option( File(".taskbar_qt4_db").addPath( Util::home() ) ) );
    XmlOptions::get().setAutoDefault( false );

};
