// $Id: TaskParser.cpp,v 1.9 2011/11/11 13:29:10 hpereira Exp $

/******************************************************************************
 *
 * Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
 *
 * This is free software; you can redistribute it and/or modify it under the
 * terms of the GNU General Public License as published by the Free Software
 * Foundation; either version 2 of the License, or (at your option) any later
 * version.
 *
 * This software is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * for more details.
 *
 * You should have received a copy of the GNU General Public License along with
 * software; if not, write to the Free Software Foundation, Inc., 59 Temple
 * Place, Suite 330, Boston, MA  02111-1307 USA
 *
 *
 *******************************************************************************/

/*!
  \file    TaskParser.cc
  \brief   task parser based on xml
  \author  Hugo Pereira
  \version $Revision: 1.9 $
  \date    $Date: 2011/11/11 13:29:10 $
*/

#include <QFile>
#include <QDomDocument>
#include <QDomElement>

#include "Debug.h"
#include "File.h"
#include "TaskParser.h"
#include "XmlDef.h"



//________________________________________________
bool TaskParser::read( const File& file )
{
  Debug::Throw( "TaskParser::Read.\n" );

  // reset attributes_list
  attributes_list_.clear();

  // parse the file
  QFile qtfile( file );
  if ( !qtfile.open( QFile::ReadOnly ) )
  {
    Debug::Throw( "Options::Read - cannot open file.\n" );
    return false;
  }

  // dom document
  QDomDocument document;
  error_ = XmlError( file );
  if ( !document.setContent( &qtfile, &error_.error(), &error_.line(), &error_.column() ) ) {
    qtfile.close();
    return false;
  }

  QDomElement doc_element = document.documentElement();
  QDomNode node = doc_element.firstChild();
  for(QDomNode node = doc_element.firstChild(); !node.isNull(); node = node.nextSibling() )
  {
    QDomElement element = node.toElement();
    if( element.isNull() ) continue;

    QString tag_name( element.tagName() );
    if( tag_name == XML::TASKBAR ) attributes_list_.push_back( TaskBarAttributes( element ) );
    else Debug::Throw(0) << "TaskParser::Read - unrecognized tag_name " << tag_name << endl;
  }

  return true;
}

//________________________________________________
bool TaskParser::write( const File& file ) const
{

  Debug::Throw() << "TaskParser::Write - file: " << file << endl;

  if( attributes_list_.empty() )
  {
    Debug::Throw(0) << "TaskParser::Write - empty attributes" << endl;
    return true;
  }

  QFile out( file );
  if( !out.open( QIODevice::WriteOnly ) )
  {
    Debug::Throw(0) << "TaskParser::write - unable to write to file " << file << endl;
    return false;
  }

  QDomDocument document;
  QDomElement top = document.createElement( XML::TASK_LIST );
  document.appendChild( top );
  for( TaskBarAttributes::List::const_iterator iter = attributes_list_.begin(); iter != attributes_list_.end(); ++iter )
  { top.appendChild( iter->domElement( document ) ); }

  // finish
  out.write( document.toByteArray() );
  out.close();

  return true;

}
